@@ -18,7 +18,7 @@ package Image::BMP;
 # CHANGELOG
 # ---------
 #
-# Version 1.24 2024/02/05
+# Version 1.25 2024/02/05
 # -----------------------
 # * Close 'bug' requesting update from indirect object creation to new method
 #
@@ -78,7 +78,7 @@ use Exporter ();
 @ISA = qw(Exporter);
 @EXPORT_OK = qw(open_file open_pipe close load colormap xy xy_rgb xy_index set save view_ascii debug remember_image ignore_imagemagick_bug add_pixel file);
 
-$VERSION = '1.24';
+$VERSION = '1.25';
 $LIBRARY = __PACKAGE__;
 
 ##################################################
@@ -817,14 +817,14 @@ Image::BMP - Bitmap parser/viewer
  use Image::BMP;
 
  # Example one:
- my $img = new Image::BMP(
+ my $img = Image::BMP->new(
 				file            => 'some.bmp',
 				debug           => 1,
 				);
  $img->view_ascii;
 
  # Example two:
- my $img2 = new Image::BMP;
+ my $img2 = Image::BMP->new();
  $img2->open_file('another.bmp');
  my $color = $img2->xy(100,100);	# Get pixel at 100,100
  my ($r,$g,$b) = $img2->xy_rgb(100,200);
@@ -840,7 +840,7 @@ It can be used to:
 
 =item Just get image info, don't read the whole image:
 
- my $img = new Image::BMP(file => 'some.bmp');
+ my $img = Image::BMP->new(file => 'some.bmp');
  print "Resolution: $img->{Width} x $img->{Height}\n";
 
 =item View images
@@ -873,7 +873,7 @@ The following data/keys are read when opening an image:
 
 =over
 
-=item $img = new Image::BMP(%options);
+=item $img = Image::BMP->new(%options);
 
 Constructs a new C<Image::BMP> object:
 
@@ -960,7 +960,7 @@ you can process all the image data yourself by supplying a callback function:
 	 my ($img,$x,$y,$r,$g,$b) = @_;
 	 print "add pixel $x,$y = $r,$g,$b\n";
  }
- my $img = new Image::BMP(file => 'some.bmp', add_pixel = \&my_add);
+ my $img = Image::BMP->new(file => 'some.bmp', add_pixel = \&my_add);
  $img->load;
 
 It may be useful to note that most bitmaps are read from left to right
